==> checker-3.7.0.jar: annotated-jdk/src/java.base/share/classes/java/io/FilterOutputStream.java <==
/*
 * Copyright (c) 1994, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.io;

import org.checkerframework.checker.index.qual.IndexOrHigh;
import org.checkerframework.checker.index.qual.LTLengthOf;
import org.checkerframework.checker.index.qual.NonNegative;
import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.checker.signedness.qual.PolySigned;
import org.checkerframework.framework.qual.AnnotatedFor;
import org.checkerframework.framework.qual.CFComment;

@CFComment({ "lock: Note that the @GuardSatisfied is for locks that are external to the implementation class." })
@AnnotatedFor({ "lock", "nullness", "index", "signedness" })
public class FilterOutputStream extends OutputStream {

    protected OutputStream out;

    public FilterOutputStream(@Nullable OutputStream out) {
    }

    @Override
    public void write(@GuardSatisfied FilterOutputStream this, @PolySigned int b) throws IOException;

    @Override
    public void write(@GuardSatisfied FilterOutputStream this, @PolySigned byte[] b) throws IOException;

    @Override
    public void write(@GuardSatisfied FilterOutputStream this, @PolySigned byte[] b, @IndexOrHigh({ "#1" }) int off, @LTLengthOf(value = { "#1" }, offset = { "#2 - 1" }) @NonNegative int len) throws IOException;

    @Override
    public void flush(@GuardSatisfied FilterOutputStream this) throws IOException;

    @Override
    public void close(@GuardSatisfied FilterOutputStream this) throws IOException;
}

==> checker-3.19.0.jar: annotated-jdk/src/java.base/share/classes/java/io/FilterOutputStream.java <==
/*
 * Copyright (c) 1994, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.io;

import org.checkerframework.checker.index.qual.IndexOrHigh;
import org.checkerframework.checker.index.qual.LTLengthOf;
import org.checkerframework.checker.index.qual.NonNegative;
import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.checker.mustcall.qual.MustCallAlias;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.checker.signedness.qual.PolySigned;
import org.checkerframework.framework.qual.AnnotatedFor;
import org.checkerframework.framework.qual.CFComment;

@CFComment({ "lock: Note that the @GuardSatisfied is for locks that are external to the implementation class." })
@AnnotatedFor({ "index", "lock", "mustcall", "nullness", "signedness" })
public class FilterOutputStream extends OutputStream {

    protected OutputStream out;

    @MustCallAlias
    public FilterOutputStream(@Nullable @MustCallAlias OutputStream out) {
    }

    @Override
    public void write(@GuardSatisfied FilterOutputStream this, @PolySigned int b) throws IOException;

    @Override
    public void write(@GuardSatisfied FilterOutputStream this, @PolySigned byte[] b) throws IOException;

    @Override
    public void write(@GuardSatisfied FilterOutputStream this, @PolySigned byte[] b, @IndexOrHigh({ "#1" }) int off, @LTLengthOf(value = { "#1" }, offset = { "#2 - 1" }) @NonNegative int len) throws IOException;

    @Override
    public void flush(@GuardSatisfied FilterOutputStream this) throws IOException;

    @Override
    public void close(@GuardSatisfied FilterOutputStream this) throws IOException;
}
